*******
Authors
*******

Leads
=====

- Steven Loria `@sloria <https://github.com/sloria>`_
- Josh Carp `@jmcarp <https://github.com/jmcarp>`_

Contributors (chronological)
============================

- Josh Johnston `@Trii <https://github.com/Trii>`_
